pub fn fetch_disk_info<T>(device: T) -> Result<Disk>where
T: ToString,Expand description
Returns Disk
Uses a platform-specific function
If platform isn’t supported it will return error ErrorKind::Unsupported
device argument must be block device path or name
e.g. “/dev/sda” or “sda”
Make sure thet device has the correct format (see above)
Otherwise, use fetch_devices and fetch_all